# abbreviation-uhh-what-is-word-for-tearing-apart-an-abbreviation
## or auwiwftaaa
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-green)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-blue)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-orange)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-yellow)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-red)

i swear dont look
<br>
please
<br>
i just made this for my friend